pub struct PhantomCovariant<T>(/* private fields */)
where
T: ?Sized;🔬This is a nightly-only experimental API. (
phantom_variance_markers #135806)Expand description
Zero-sized type used to mark a type parameter as covariant.
Types used as part of the return value from a function are covariant. If the type is also passed as a parameter then it is invariant. See the reference for more information.
Note: If T is otherwise contravariant or invariant, the resulting type is invariant.
Layout
For all T, the following are guaranteed:
size_of::<PhantomCovariant<T>>() == 0align_of::<PhantomCovariant<T>>() == 1
Implementations