Unpin

Trait Unpin 

1.33.0 ยท Source
pub auto trait Unpin { }
Types that do not require any pinning guarantees.

For information on what โ€œpinningโ€ is, see the pin module documentation.

Implementing the Unpin trait for T expresses the fact that T is pinning-agnostic: it shall not expose nor rely on any pinning guarantees. This, in turn, means that a Pin-wrapped pointer to such a type can feature a fully unrestricted API. In other words, if T: Unpin, a value of type T will not be bound by the invariants which pinning otherwise offers, even when โ€œpinnedโ€ by a Pin<Ptr> pointing at it. When a value of type T is pointed at by a Pin<Ptr>, Pin will not restrict access to the pointee value like it normally would, thus allowing the user to do anything that they normally could with a non-Pin-wrapped Ptr to that value.

The idea of this trait is to alleviate the reduced ergonomics of APIs that require the use of Pin for soundness for some types, but which also want to be used by other types that donโ€™t care about pinning. The prime example of such an API is Future::poll. There are many Future types that donโ€™t care about pinning. These futures can implement Unpin and therefore get around the pinning related restrictions in the API, while still allowing the subset of Futures which do require pinning to be implemented soundly.

For more discussion on the consequences of Unpin within the wider scope of the pinning system, see the section about Unpin in the pin module.

Unpin has no consequence at all for non-pinned data. In particular, mem::replace happily moves !Unpin data, which would be immovable when pinned (mem::replace works for any &mut T, not just when T: Unpin).

However, you cannot use mem::replace on !Unpin data which is pinned by being wrapped inside a Pin<Ptr> pointing at it. This is because you cannot (safely) use a Pin<Ptr> to get a &mut T to its pointee value, which you would need to call mem::replace, and that is what makes this system work.

So this, for example, can only be done on types implementing Unpin:

use std::mem;
use std::pin::Pin;

let mut string = "this".to_string();
let mut pinned_string = Pin::new(&mut string);

// We need a mutable reference to call `mem::replace`.
// We can obtain such a reference by (implicitly) invoking `Pin::deref_mut`,
// but that is only possible because `String` implements `Unpin`.
mem::replace(&mut *pinned_string, "other".to_string());

This trait is automatically implemented for almost every type. The compiler is free to take the conservative stance of marking types as Unpin so long as all of the types that compose its fields are also Unpin. This is because if a type implements Unpin, then it is unsound for that typeโ€™s implementation to rely on pinning-related guarantees for soundness, even when viewed through a โ€œpinningโ€ pointer! It is the responsibility of the implementor of a type that relies upon pinning for soundness to ensure that type is not marked as Unpin by adding PhantomPinned field. For more details, see the pin module docs.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.33.0 ยท Source

impl !Unpin for PhantomPinned

Source

impl Unpin for LocalWaker

1.36.0 ยท Source

impl Unpin for Waker

Source

impl<Dyn: PointeeSized> Unpin for DynMetadata<Dyn>

1.64.0 ยท Source

impl<F: Unpin> Unpin for PollFn<F>

Source

impl<I> Unpin for FromIter<I>

Source

impl<T: ?Sized> !Unpin for UnsafePinned<T>

When this type is used, that almost certainly means safe APIs need to use pinning to avoid the aliases from becoming invalidated. Therefore letโ€™s mark this as !Unpin. You can always opt back in to Unpin with an impl block, provided your API is still sound while unpinned.

1.33.0 ยท Source

impl<T: PointeeSized> Unpin for &T

1.33.0 ยท Source

impl<T: PointeeSized> Unpin for &mut T

1.38.0 ยท Source

impl<T: PointeeSized> Unpin for *const T

Source

impl<T: PointeeSized> Unpin for *const T is !null

1.38.0 ยท Source

impl<T: PointeeSized> Unpin for *mut T

1.28.0 ยท Source

impl<T> Unpin for NonZero<T>

1.48.0 ยท Source

impl<T> Unpin for Ready<T>

Auto implementors



impl Unpin for !



impl Unpin for ()



impl Unpin for Abi



impl Unpin for AddrParseError



impl Unpin for core::mem::Alignment



impl Unpin for core::fmt::Alignment



impl Unpin for AllocError



impl Unpin for Array



impl Unpin for AsciiChar



impl Unpin for Assume



impl Unpin for AtomicOrdering



impl Unpin for BasicBlock



impl Unpin for Bool



impl Unpin for BorrowError



impl Unpin for BorrowMutError



impl Unpin for ByteStr



impl Unpin for CStr



impl Unpin for Char



impl Unpin for CharCase



impl Unpin for CharTryFromError



impl Unpin for Const



impl Unpin for CpuidResult



impl Unpin for DebugAsHex



impl Unpin for DecodeUtf16Error



impl Unpin for Duration



impl Unpin for DynTrait



impl Unpin for DynTraitPredicate



impl Unpin for core::io::Empty



impl Unpin for Enum



impl Unpin for core::io::Error



impl Unpin for core::fmt::Error



impl Unpin for ErrorKind



impl Unpin for core::char::EscapeDebug



impl Unpin for core::ascii::EscapeDefault



impl Unpin for core::char::EscapeDefault



impl Unpin for core::char::EscapeUnicode



impl Unpin for Field



impl Unpin for FieldId



impl Unpin for Float



impl Unpin for FnPtr



impl Unpin for FormattingOptions



impl Unpin for FpCategory



impl Unpin for FromBytesUntilNulError



impl Unpin for FromBytesWithNulError



impl Unpin for Generic



impl Unpin for GenericType



impl Unpin for GetDisjointMutError



impl Unpin for core::arch::hexagon::v64::HvxVector



impl Unpin for core::arch::hexagon::v128::HvxVector



impl Unpin for core::arch::hexagon::v64::HvxVectorPair



impl Unpin for core::arch::hexagon::v128::HvxVectorPair



impl Unpin for core::arch::hexagon::v64::HvxVectorPred



impl Unpin for core::arch::hexagon::v128::HvxVectorPred



impl Unpin for Infallible



impl Unpin for Int



impl Unpin for IntErrorKind



impl Unpin for IpAddr



impl Unpin for Ipv4Addr



impl Unpin for Ipv6Addr



impl Unpin for Ipv6MulticastScope



impl Unpin for Last



impl Unpin for Layout



impl Unpin for LayoutError



impl Unpin for Lifetime



impl Unpin for Locality



impl Unpin for OneSidedRangeBound



impl Unpin for core::cmp::Ordering



impl Unpin for core::sync::atomic::Ordering



impl Unpin for ParseBoolError



impl Unpin for ParseCharError



impl Unpin for ParseFloatError



impl Unpin for ParseIntError



impl Unpin for Pointer



impl Unpin for RangeFull



impl Unpin for RawWaker



impl Unpin for RawWakerVTable



impl Unpin for Reference



impl Unpin for core::io::Repeat



impl Unpin for ReturnToArg



impl Unpin for SY



impl Unpin for SearchStep



impl Unpin for Sign



impl Unpin for SimdAlign



impl Unpin for Sink



impl Unpin for SipHasher



impl Unpin for Slice



impl Unpin for SocketAddr



impl Unpin for SocketAddrV4



impl Unpin for SocketAddrV6



impl Unpin for Str



impl Unpin for Struct



impl Unpin for ToCasefold



impl Unpin for ToLowercase



impl Unpin for ToTitlecase



impl Unpin for ToUppercase



impl Unpin for Trait



impl Unpin for TryFromCharError



impl Unpin for TryFromFloatSecsError



impl Unpin for TryFromIntError



impl Unpin for TryFromSliceError



impl Unpin for Tuple



impl Unpin for Type



impl Unpin for TypeId



impl Unpin for TypeKind



impl Unpin for Union



impl Unpin for UnwindActionArg



impl Unpin for UnwindTerminateReason



impl Unpin for Utf8Error



impl Unpin for Variant



impl Unpin for __m128



impl Unpin for __m256



impl Unpin for __m512



impl Unpin for __m128bh



impl Unpin for __m128d



impl Unpin for __m128h



impl Unpin for __m128i



impl Unpin for __m256bh



impl Unpin for __m256d



impl Unpin for __m256h



impl Unpin for __m256i



impl Unpin for __m512bh



impl Unpin for __m512d



impl Unpin for __m512h



impl Unpin for __m512i



impl Unpin for __tile1024i



impl Unpin for bf16



impl Unpin for bool



impl Unpin for c_void



impl Unpin for char



impl Unpin for f16



impl Unpin for f32



impl Unpin for f64



impl Unpin for f16x2



impl Unpin for f128



impl Unpin for float16x4_t



impl Unpin for float16x4x2_t



impl Unpin for float16x4x3_t



impl Unpin for float16x4x4_t



impl Unpin for float16x8_t



impl Unpin for float16x8x2_t



impl Unpin for float16x8x3_t



impl Unpin for float16x8x4_t



impl Unpin for float32x2_t



impl Unpin for float32x2x2_t



impl Unpin for float32x2x3_t



impl Unpin for float32x2x4_t



impl Unpin for float32x4_t



impl Unpin for float32x4x2_t



impl Unpin for float32x4x3_t



impl Unpin for float32x4x4_t



impl Unpin for float64x1_t



impl Unpin for float64x1x2_t



impl Unpin for float64x1x3_t



impl Unpin for float64x1x4_t



impl Unpin for float64x2_t



impl Unpin for float64x2x2_t



impl Unpin for float64x2x3_t



impl Unpin for float64x2x4_t



impl Unpin for i8



impl Unpin for i16



impl Unpin for i32



impl Unpin for i64



impl Unpin for i128



impl Unpin for int8x8_t



impl Unpin for int8x8x2_t



impl Unpin for int8x8x3_t



impl Unpin for int8x8x4_t



impl Unpin for int8x16_t



impl Unpin for int8x16x2_t



impl Unpin for int8x16x3_t



impl Unpin for int8x16x4_t



impl Unpin for int16x4_t



impl Unpin for int16x4x2_t



impl Unpin for int16x4x3_t



impl Unpin for int16x4x4_t



impl Unpin for int16x8_t



impl Unpin for int16x8x2_t



impl Unpin for int16x8x3_t



impl Unpin for int16x8x4_t



impl Unpin for int32x2_t



impl Unpin for int32x2x2_t



impl Unpin for int32x2x3_t



impl Unpin for int32x2x4_t



impl Unpin for int32x4_t



impl Unpin for int32x4x2_t



impl Unpin for int32x4x3_t



impl Unpin for int32x4x4_t



impl Unpin for int64x1_t



impl Unpin for int64x1x2_t



impl Unpin for int64x1x3_t



impl Unpin for int64x1x4_t



impl Unpin for int64x2_t



impl Unpin for int64x2x2_t



impl Unpin for int64x2x3_t



impl Unpin for int64x2x4_t



impl Unpin for isize



impl Unpin for m128



impl Unpin for m256



impl Unpin for m128d



impl Unpin for m128i



impl Unpin for m256d



impl Unpin for m256i



impl Unpin for objc_class



impl Unpin for objc_selector



impl Unpin for poly8x8_t



impl Unpin for poly8x8x2_t



impl Unpin for poly8x8x3_t



impl Unpin for poly8x8x4_t



impl Unpin for poly8x16_t



impl Unpin for poly8x16x2_t



impl Unpin for poly8x16x3_t



impl Unpin for poly8x16x4_t



impl Unpin for poly16x4_t



impl Unpin for poly16x4x2_t



impl Unpin for poly16x4x3_t



impl Unpin for poly16x4x4_t



impl Unpin for poly16x8_t



impl Unpin for poly16x8x2_t



impl Unpin for poly16x8x3_t



impl Unpin for poly16x8x4_t



impl Unpin for poly64x1_t



impl Unpin for poly64x1x2_t



impl Unpin for poly64x1x3_t



impl Unpin for poly64x1x4_t



impl Unpin for poly64x2_t



impl Unpin for poly64x2x2_t



impl Unpin for poly64x2x3_t



impl Unpin for poly64x2x4_t



impl Unpin for str



impl Unpin for svbool_t



impl Unpin for svfloat32_t



impl Unpin for svfloat32x2_t



impl Unpin for svfloat32x3_t



impl Unpin for svfloat32x4_t



impl Unpin for svfloat64_t



impl Unpin for svfloat64x2_t



impl Unpin for svfloat64x3_t



impl Unpin for svfloat64x4_t



impl Unpin for svint8_t



impl Unpin for svint8x2_t



impl Unpin for svint8x3_t



impl Unpin for svint8x4_t



impl Unpin for svint16_t



impl Unpin for svint16x2_t



impl Unpin for svint16x3_t



impl Unpin for svint16x4_t



impl Unpin for svint32_t



impl Unpin for svint32x2_t



impl Unpin for svint32x3_t



impl Unpin for svint32x4_t



impl Unpin for svint64_t



impl Unpin for svint64x2_t



impl Unpin for svint64x3_t



impl Unpin for svint64x4_t



impl Unpin for svpattern



impl Unpin for svprfop



impl Unpin for svuint8_t



impl Unpin for svuint8x2_t



impl Unpin for svuint8x3_t



impl Unpin for svuint8x4_t



impl Unpin for svuint16_t



impl Unpin for svuint16x2_t



impl Unpin for svuint16x3_t



impl Unpin for svuint16x4_t



impl Unpin for svuint32_t



impl Unpin for svuint32x2_t



impl Unpin for svuint32x3_t



impl Unpin for svuint32x4_t



impl Unpin for svuint64_t



impl Unpin for svuint64x2_t



impl Unpin for svuint64x3_t



impl Unpin for svuint64x4_t



impl Unpin for u8



impl Unpin for u16



impl Unpin for u32



impl Unpin for u64



impl Unpin for u128



impl Unpin for uint8x8_t



impl Unpin for uint8x8x2_t



impl Unpin for uint8x8x3_t



impl Unpin for uint8x8x4_t



impl Unpin for uint8x16_t



impl Unpin for uint8x16x2_t



impl Unpin for uint8x16x3_t



impl Unpin for uint8x16x4_t



impl Unpin for uint16x4_t



impl Unpin for uint16x4x2_t



impl Unpin for uint16x4x3_t



impl Unpin for uint16x4x4_t



impl Unpin for uint16x8_t



impl Unpin for uint16x8x2_t



impl Unpin for uint16x8x3_t



impl Unpin for uint16x8x4_t



impl Unpin for uint32x2_t



impl Unpin for uint32x2x2_t



impl Unpin for uint32x2x3_t



impl Unpin for uint32x2x4_t



impl Unpin for uint32x4_t



impl Unpin for uint32x4x2_t



impl Unpin for uint32x4x3_t



impl Unpin for uint32x4x4_t



impl Unpin for uint64x1_t



impl Unpin for uint64x1x2_t



impl Unpin for uint64x1x3_t



impl Unpin for uint64x1x4_t



impl Unpin for uint64x2_t



impl Unpin for uint64x2x2_t



impl Unpin for uint64x2x3_t



impl Unpin for uint64x2x4_t



impl Unpin for usize



impl Unpin for v128



impl Unpin for core::arch::powerpc::vector_bool_char



impl Unpin for core::arch::s390x::vector_bool_char



impl Unpin for core::arch::powerpc::vector_bool_int



impl Unpin for core::arch::s390x::vector_bool_int



impl Unpin for vector_bool_long



impl Unpin for vector_bool_long_long



impl Unpin for core::arch::powerpc::vector_bool_short



impl Unpin for core::arch::s390x::vector_bool_short



impl Unpin for core::arch::powerpc::vector_double



impl Unpin for core::arch::s390x::vector_double



impl Unpin for core::arch::powerpc::vector_float



impl Unpin for core::arch::s390x::vector_float



impl Unpin for core::arch::powerpc::vector_signed_char



impl Unpin for core::arch::s390x::vector_signed_char



impl Unpin for core::arch::powerpc::vector_signed_int



impl Unpin for core::arch::s390x::vector_signed_int



impl Unpin for vector_signed_long



impl Unpin for vector_signed_long_long



impl Unpin for core::arch::powerpc::vector_signed_short



impl Unpin for core::arch::s390x::vector_signed_short



impl Unpin for core::arch::powerpc::vector_unsigned_char



impl Unpin for core::arch::s390x::vector_unsigned_char



impl Unpin for core::arch::powerpc::vector_unsigned_int



impl Unpin for core::arch::s390x::vector_unsigned_int



impl Unpin for vector_unsigned_long



impl Unpin for vector_unsigned_long_long



impl Unpin for core::arch::powerpc::vector_unsigned_short



impl Unpin for core::arch::s390x::vector_unsigned_short



impl<'a, 'b, const N: usize> Unpin for CharArrayRefSearcher<'a, 'b, N>



impl<'a, 'b> Unpin for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Unpin for DebugList<'a, 'b>



impl<'a, 'b> Unpin for DebugMap<'a, 'b>



impl<'a, 'b> Unpin for DebugSet<'a, 'b>



impl<'a, 'b> Unpin for DebugStruct<'a, 'b>



impl<'a, 'b> Unpin for DebugTuple<'a, 'b>



impl<'a, 'b> Unpin for StrSearcher<'a, 'b>



impl<'a, A> Unpin for core::option::Iter<'a, A>



impl<'a, A> Unpin for core::option::IterMut<'a, A>



impl<'a, F> Unpin for CharPredicateSearcher<'a, F>
where F: Unpin,



impl<'a, I> Unpin for ByRefSized<'a, I>



impl<'a, P> Unpin for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, P> Unpin for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, P> Unpin for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, P> Unpin for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, P> Unpin for core::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, P> Unpin for core::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, P> Unpin for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, P> Unpin for core::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, P> Unpin for core::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, P> Unpin for core::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, P> Unpin for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Unpin,



impl<'a, T, P> Unpin for ChunkBy<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for ChunkByMut<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for core::slice::RSplit<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for RSplitMut<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for core::slice::RSplitN<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for RSplitNMut<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for core::slice::Split<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for core::slice::SplitInclusive<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for SplitInclusiveMut<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for SplitMut<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for core::slice::SplitN<'a, T, P>
where P: Unpin,



impl<'a, T, P> Unpin for SplitNMut<'a, T, P>
where P: Unpin,



impl<'a, T, const N: usize> Unpin for ArrayWindows<'a, T, N>



impl<'a, T> Unpin for BorrowedCursor<'a, T>



impl<'a, T> Unpin for Chunks<'a, T>



impl<'a, T> Unpin for ChunksExact<'a, T>



impl<'a, T> Unpin for ChunksExactMut<'a, T>



impl<'a, T> Unpin for ChunksMut<'a, T>



impl<'a, T> Unpin for core::result::Iter<'a, T>



impl<'a, T> Unpin for core::slice::Iter<'a, T>



impl<'a, T> Unpin for core::result::IterMut<'a, T>



impl<'a, T> Unpin for core::slice::IterMut<'a, T>



impl<'a, T> Unpin for RChunks<'a, T>



impl<'a, T> Unpin for RChunksExact<'a, T>



impl<'a, T> Unpin for RChunksExactMut<'a, T>



impl<'a, T> Unpin for RChunksMut<'a, T>



impl<'a, T> Unpin for Windows<'a, T>



impl<'a, const N: usize> Unpin for CharArraySearcher<'a, N>



impl<'a> !Unpin for Request<'a>



impl<'a> Unpin for Arguments<'a>



impl<'a> Unpin for core::ffi::c_str::Bytes<'a>



impl<'a> Unpin for core::str::Bytes<'a>



impl<'a> Unpin for CharIndices<'a>



impl<'a> Unpin for CharSearcher<'a>



impl<'a> Unpin for Chars<'a>



impl<'a> Unpin for Context<'a>



impl<'a> Unpin for ContextBuilder<'a>



impl<'a> Unpin for EncodeUtf16<'a>



impl<'a> Unpin for EscapeAscii<'a>



impl<'a> Unpin for core::str::EscapeDebug<'a>



impl<'a> Unpin for core::str::EscapeDefault<'a>



impl<'a> Unpin for core::str::EscapeUnicode<'a>



impl<'a> Unpin for Formatter<'a>



impl<'a> Unpin for IoSlice<'a>



impl<'a> Unpin for IoSliceMut<'a>



impl<'a> Unpin for Lines<'a>



impl<'a> Unpin for LinesAny<'a>



impl<'a> Unpin for Location<'a>



impl<'a> Unpin for PanicInfo<'a>



impl<'a> Unpin for PanicMessage<'a>



impl<'a> Unpin for PhantomContravariantLifetime<'a>



impl<'a> Unpin for PhantomCovariantLifetime<'a>



impl<'a> Unpin for PhantomInvariantLifetime<'a>



impl<'a> Unpin for Source<'a>



impl<'a> Unpin for SplitAsciiWhitespace<'a>



impl<'a> Unpin for SplitWhitespace<'a>



impl<'a> Unpin for Utf8Chunk<'a>



impl<'a> Unpin for Utf8Chunks<'a>



impl<'a> Unpin for Utf8Pattern<'a>



impl<'a> Unpin for VaList<'a>



impl<'b, T> Unpin for Ref<'b, T>
where T: ?Sized,



impl<'b, T> Unpin for RefMut<'b, T>
where T: ?Sized,



impl<'data, T> Unpin for BorrowedBuf<'data, T>



impl<A, B> Unpin for core::iter::Chain<A, B>
where A: Unpin, B: Unpin,



impl<A, B> Unpin for Zip<A, B>
where A: Unpin, B: Unpin,



impl<A> Unpin for core::option::IntoIter<A>
where A: Unpin,



impl<A> Unpin for OptionFlatten<A>
where A: Unpin,



impl<A> Unpin for RangeFromIter<A>
where A: Unpin,



impl<A> Unpin for RangeInclusiveIter<A>
where A: Unpin,



impl<A> Unpin for RangeIter<A>
where A: Unpin,



impl<A> Unpin for core::iter::Repeat<A>
where A: Unpin,



impl<A> Unpin for RepeatN<A>
where A: Unpin,



impl<B, C> Unpin for ControlFlow<B, C>
where C: Unpin, B: Unpin,



impl<F> Unpin for core::iter::FromFn<F>
where F: Unpin,



impl<F> Unpin for core::fmt::FromFn<F>
where F: Unpin,



impl<F> Unpin for OnceWith<F>
where F: Unpin,



impl<F> Unpin for RepeatWith<F>
where F: Unpin,



impl<G> Unpin for FromCoroutine<G>
where G: Unpin,



impl<H> Unpin for BuildHasherDefault<H>



impl<I, F, const N: usize> Unpin for MapWindows<I, F, N>
where F: Unpin, I: Unpin, <I as Iterator>::Item: Unpin,



impl<I, F> Unpin for FilterMap<I, F>
where I: Unpin, F: Unpin,



impl<I, F> Unpin for Inspect<I, F>
where I: Unpin, F: Unpin,



impl<I, F> Unpin for Map<I, F>
where I: Unpin, F: Unpin,



impl<I, G> Unpin for IntersperseWith<I, G>
where G: Unpin, I: Unpin, <I as Iterator>::Item: Unpin,



impl<I, P> Unpin for Filter<I, P>
where I: Unpin, P: Unpin,



impl<I, P> Unpin for MapWhile<I, P>
where I: Unpin, P: Unpin,



impl<I, P> Unpin for SkipWhile<I, P>
where I: Unpin, P: Unpin,



impl<I, P> Unpin for TakeWhile<I, P>
where I: Unpin, P: Unpin,



impl<I, St, F> Unpin for Scan<I, St, F>
where I: Unpin, F: Unpin, St: Unpin,



impl<I, U, F> Unpin for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Unpin, I: Unpin, F: Unpin,



impl<I, const N: usize> Unpin for ArrayChunks<I, N>
where I: Unpin, <I as Iterator>::Item: Unpin,



impl<I> Unpin for Cloned<I>
where I: Unpin,



impl<I> Unpin for Copied<I>
where I: Unpin,



impl<I> Unpin for Cycle<I>
where I: Unpin,



impl<I> Unpin for DecodeUtf16<I>
where I: Unpin,



impl<I> Unpin for Enumerate<I>
where I: Unpin,



impl<I> Unpin for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Unpin, I: Unpin,



impl<I> Unpin for Fuse<I>
where I: Unpin,



impl<I> Unpin for Intersperse<I>
where <I as Iterator>::Item: Sized + Unpin, I: Unpin,



impl<I> Unpin for Peekable<I>
where I: Unpin, <I as Iterator>::Item: Unpin,



impl<I> Unpin for Skip<I>
where I: Unpin,



impl<I> Unpin for StepBy<I>
where I: Unpin,



impl<I> Unpin for core::iter::Take<I>
where I: Unpin,



impl<Idx> Unpin for Clamp<Idx>
where Idx: Unpin,



impl<Idx> Unpin for core::ops::Range<Idx>
where Idx: Unpin,



impl<Idx> Unpin for core::range::Range<Idx>
where Idx: Unpin,



impl<Idx> Unpin for core::ops::RangeFrom<Idx>
where Idx: Unpin,



impl<Idx> Unpin for core::range::RangeFrom<Idx>
where Idx: Unpin,



impl<Idx> Unpin for core::ops::RangeInclusive<Idx>
where Idx: Unpin,



impl<Idx> Unpin for core::range::RangeInclusive<Idx>
where Idx: Unpin,



impl<Idx> Unpin for RangeTo<Idx>
where Idx: Unpin,



impl<Idx> Unpin for core::ops::RangeToInclusive<Idx>
where Idx: Unpin,



impl<Idx> Unpin for core::range::RangeToInclusive<Idx>
where Idx: Unpin,



impl<P> Unpin for MaybeDangling<P>
where P: Unpin + ?Sized,



impl<Ptr> Unpin for Pin<Ptr>
where Ptr: Unpin,



impl<Ret, T> Unpin for fn(Tโ‚, Tโ‚‚, โ€ฆ, Tโ‚™) -> Ret



impl<T, E> Unpin for Result<T, E>
where T: Unpin, E: Unpin,



impl<T, F> Unpin for DropGuard<T, F>
where T: Unpin, F: Unpin,



impl<T, F> Unpin for LazyCell<T, F>
where F: Unpin, T: Unpin,



impl<T, F> Unpin for Successors<T, F>
where F: Unpin, T: Unpin,



impl<T, U> Unpin for core::io::Chain<T, U>
where T: Unpin, U: Unpin,



impl<T, const N: usize> Unpin for core::array::IntoIter<T, N>
where T: Unpin,



impl<T, const N: usize> Unpin for Mask<T, N>
where T: Unpin,



impl<T, const N: usize> Unpin for Simd<T, N>
where T: Unpin,



impl<T, const N: usize> Unpin for [MaybeUninit<T>; N]
where T: Unpin,



impl<T, const N: usize> Unpin for [Option<T>; N]
where T: Unpin,



impl<T, const N: usize> Unpin for [T; N]
where T: Unpin,



impl<T, const VARIANT: u32, const FIELD: u32> Unpin for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,



impl<T> Unpin for (Tโ‚, Tโ‚‚, โ€ฆ, Tโ‚™)
where T: Unpin,



impl<T> Unpin for AssertUnwindSafe<T>
where T: Unpin,



impl<T> Unpin for Atomic<T>
where <T as AtomicPrimitive>::Storage: Unpin,



impl<T> Unpin for Bound<T>
where T: Unpin,



impl<T> Unpin for Cell<T>
where T: Unpin + ?Sized,



impl<T> Unpin for Cursor<T>
where T: Unpin,



impl<T> Unpin for Discriminant<T>



impl<T> Unpin for core::iter::Empty<T>



impl<T> Unpin for core::result::IntoIter<T>
where T: Unpin,



impl<T> Unpin for ManuallyDrop<T>
where T: Unpin + ?Sized,



impl<T> Unpin for MaybeUninit<T>
where T: Unpin,



impl<T> Unpin for NonNull<T>
where T: ?Sized,



impl<T> Unpin for NumBuffer<T>
where <T as NumBufferTrait>::Buf: Unpin, T: Unpin,



impl<T> Unpin for Once<T>
where T: Unpin,



impl<T> Unpin for OnceCell<T>
where T: Unpin,



impl<T> Unpin for Option<T>
where T: Unpin,



impl<T> Unpin for Pending<T>



impl<T> Unpin for PhantomContravariant<T>
where T: ?Sized,



impl<T> Unpin for PhantomCovariant<T>
where T: ?Sized,



impl<T> Unpin for PhantomData<T>
where T: Unpin + ?Sized,



impl<T> Unpin for PhantomInvariant<T>
where T: ?Sized,



impl<T> Unpin for Poll<T>
where T: Unpin,



impl<T> Unpin for RefCell<T>
where T: Unpin + ?Sized,



impl<T> Unpin for Rev<T>
where T: Unpin,



impl<T> Unpin for Reverse<T>
where T: Unpin,



impl<T> Unpin for Saturating<T>
where T: Unpin,



impl<T> Unpin for SyncUnsafeCell<T>
where T: Unpin + ?Sized,



impl<T> Unpin for SyncView<T>
where T: Unpin + ?Sized,



impl<T> Unpin for core::io::Take<T>
where T: Unpin,



impl<T> Unpin for TraitImpl<T>
where T: ?Sized,



impl<T> Unpin for UnsafeCell<T>
where T: Unpin + ?Sized,



impl<T> Unpin for Wrapping<T>
where T: Unpin,



impl<T> Unpin for Yeet<T>
where T: Unpin,



impl<T> Unpin for [T]
where T: Unpin,



impl<Y, R> Unpin for CoroutineState<Y, R>
where Y: Unpin, R: Unpin,



impl<const N: usize> Unpin for [u8; N]